summaryrefslogtreecommitdiffstats
path: root/libkdegames/kgame/kgameio.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commita13e26c2f1eb3c5be81acf4f571dd4bafac10199 (patch)
tree1f1d3e407ae668b1448847970b2f1b626083faf6 /libkdegames/kgame/kgameio.h
parent24c5cdc2737fe0044b11a12359606973eb93fc0b (diff)
downloadtdegames-a13e26c2f1eb3c5be81acf4f571dd4bafac10199.tar.gz
tdegames-a13e26c2f1eb3c5be81acf4f571dd4bafac10199.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegames@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkdegames/kgame/kgameio.h')
-rw-r--r--libkdegames/kgame/kgameio.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/libkdegames/kgame/kgameio.h b/libkdegames/kgame/kgameio.h
index 6f6a6ae9..510ab0b7 100644
--- a/libkdegames/kgame/kgameio.h
+++ b/libkdegames/kgame/kgameio.h
@@ -199,9 +199,9 @@ public:
* this,TQT_SLOT(slotKeyInput(KGameIO *,TQDataStream &,TQKeyEvent *,bool *)));
* \endcode
*
* @param tqparent The parents widget whose keyboard events * should be grabbed
*/
- KGameKeyIO(TQWidget *tqparent);
+ KGameKeyIO(TQWidget *parent);
virtual ~KGameKeyIO();
/**
@@ -265,10 +265,10 @@ public:
* this,TQT_SLOT(slotMouseInput(KGameIO *,TQDataStream &,TQMouseEvent *,bool *)));
* \endcode
*
* @param tqparent The widget whose events should be captured
* @param trackmouse enables mouse tracking (gives mouse move events)
*/
- KGameMouseIO(TQWidget *tqparent,bool trackmouse=false);
+ KGameMouseIO(TQWidget *parent,bool trackmouse=false);
virtual ~KGameMouseIO();
/**
@@ -199,9 +199,9 @@ public:
* \endcode
*
- * @param tqparent The parents widget whose keyboard events * should be grabbed
+ * @param parent The parents widget whose keyboard events * should be grabbed
*/
@@ -265,10 +265,10 @@ public:
* \endcode
*
- * @param tqparent The widget whose events should be captured
+ * @param parent The widget whose events should be captured
* @param trackmouse enables mouse tracking (gives mouse move events)
*/